YARP 3.4.4 (2021-05-19)                                                {#v3_4_4}
=======================

[TOC]

YARP 3.4.4 Release Notes
========================


A (partial) list of bug fixed and issues resolved in this release can be found
[here](https://github.com/robotology/yarp/issues?q=label%3A%22Fixed+in%3A+YARP+v3.4.4%22).


Bug Fixes
---------

### Build System

* Fixed use of `CMAKE_INSTALL_PYTHON3DIR` CMake variable to specify the
  installation path of Python bindings, as in previous versions the variable
  was defined but ignored (#2523).
* Fixed the build of Python bindings on Windows (#2525, #2527).


### Libraries

### `conf`

* Fixed float128_t where long double is 64 bit (#2510).

#### `os`

* If in a `yarp::os::NetworkClock` a clock reset is detected, fill the gap
  between the waiter and the time published by the network clock port.
  A network clock reset is defined as a jump in the past of the time published
  by the network clock port.
  This fix avoids that all the threads that are waiting a
  `yarp::os::NetworkClock::delay` call on that network clock remain blocked when
  a time reset occurs  (#800, #2494).
* Fixed error in race condition during the scan of plugins in
  `YarpPluginSelector`, avoided concurrent access to variables (#2538).


### Tools

#### `yarplogger`

* Fixed crash when attempting to clear a selected log with its log tab opened
  (#2554).


### Bindings

#### Python

* Added `example_callback.py`, which showcases a `BufferedPort` with an attached
  callback handler for logging incoming bottles (#2555).

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v3.4.3..v3.4.4`):

```
    25	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
     4	Bartek Łukawski <bwmn.peter@gmail.com>
     4	Silvio Traversaro <silvio@traversaro.it>
     3	Stefano Bernagozzi <stefano.bernagozzi@iit.it>
     1	Ettore Landini <ettore.landini@iit.it>
     1	Giuseppe <gl.giuseppelerario@gmail.com>
     1	Nicolò Genesio <nicolo.genesio@iit.it>
     1	Silvio Traversaro <silvio.traversaro@iit.it>
```
